@@ -44,10 +44,10 @@
 class CustomTitle : public KTitleWidget
 {
 public:
-    CustomTitle(QWidget *parent = nullptr);
+    explicit CustomTitle(QWidget *parent = nullptr);
 
 protected:
-    void paintEvent(QPaintEvent *event);
+    void paintEvent(QPaintEvent *event) override;
     void colorsChanged();
 };
 
@@ -198,39 +198,23 @@ KCModuleInfo *ModuleView::activeModule() const
     return d->mModules.value(d->mPageWidget->currentPage());
 }
 
-const KAboutData *ModuleView::aboutData() const
-{
-    KCModuleProxy *activeModule = d->mPages.value(d->mPageWidget->currentPage());
-    KAboutData *aboutData = nullptr;
-    if (activeModule) {
-        aboutData = const_cast<KAboutData *>(activeModule->aboutData());
-    }
-    return aboutData;
-}
-
 void ModuleView::loadModule(const QModelIndex &menuItem, const QStringList &args)
 {
     if (!menuItem.isValid()) {
         return;
     }
 
-    QList<QModelIndex> indexes;
-
     MenuItem *item = menuItem.data(Qt::UserRole).value<MenuItem *>();
 
-    if (!item->item().library().isEmpty() || !item->service()->exec().isEmpty()) {
-        indexes << menuItem;
+    // if module has a main page (like in Appearance > Global Theme) we'll load that
+    if (!item->item().library().isEmpty() || item->isExternalAppModule()) {
+        addModule(&item->item(), args);
     }
-
-    for (int done = 0; menuItem.model()->rowCount(menuItem) > done; done = 1 + done) {
-        indexes << menuItem.model()->index(done, 0, menuItem);
+    // if module doesn't have a main page, we'll load the first subpage
+    else if (menuItem.model()->rowCount(menuItem) > 0) {
+        MenuItem *subpageItem = menuItem.model()->index(0, 0, menuItem).data(Qt::UserRole).value<MenuItem *>();
+        addModule(&subpageItem->item(), args);
     }
-
-    foreach (const QModelIndex &module, indexes) {
-        MenuItem *newMenuItem = module.data(Qt::UserRole).value<MenuItem *>();
-        addModule(&newMenuItem->item(), args);
-    }
-    // changing state is not needed here as the adding / changing of pages does it
 }
 
 void ModuleView::addModule(KCModuleInfo *module, const QStringList &args)
@@ -267,7 +251,7 @@ void ModuleView::addModule(KCModuleInfo *module, const QStringList &args)
 
     if (module->service()->hasServiceType(QStringLiteral("SystemSettingsExternalApp")) || // Is it an external app?
         module->service()->substituteUid()) { // ...or does it require UID substitution?
-        QWidget *externalWidget = new ExternalAppModule(this, module);
+        QWidget *externalWidget = new ExternalAppModule(this, module->service());
         moduleScroll->setWidget(externalWidget);
     } else { // It must be a normal module then
         KCModuleProxy *moduleProxy = new KCModuleProxy(*module, moduleScroll, args);
